summaryrefslogtreecommitdiffstats
path: root/kcron/ktlistvars.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcron/ktlistvars.h')
-rw-r--r--kcron/ktlistvars.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kcron/ktlistvars.h b/kcron/ktlistvars.h
index b338082..91a145a 100644
--- a/kcron/ktlistvars.h
+++ b/kcron/ktlistvars.h
@@ -22,7 +22,7 @@
class QString;
/**
* QListViewItem of a "variables" folder.
*/
class KTListVars : public KTListItem
{
@@ -36,12 +36,12 @@ public:
/**
* Construct variables folder from root.
*/
- KTListVars(QListView* parent, CTCron* _ctcron);
+ KTListVars(TQListView* parent, CTCron* _ctcron);
/**
* Internationalized description.
*/
- static QString getDescription();
+ static TQString getDescription();
/**
* Refresh.
@@ -22,7 +22,7 @@
class QString;
/**
- * QListViewItem of a "variables" folder.
+ * TQListViewItem of a "variables" folder.
*/
class KTListVars : public KTListItem